django-withings
===============
[![Build Status](https://travis-ci.org/orcasgit/django-withings.svg?branch=master)](https://travis-ci.org/orcasgit/django-withings) [![Coverage Status](https://coveralls.io/repos/orcasgit/django-withings/badge.png)](https://coveralls.io/r/orcasgit/django-withings) [![Requirements Status](https://requires.io/github/orcasgit/django-withings/requirements.png?branch=master)](https://requires.io/github/orcasgit/django-withings/requirements/?branch=master)

Django-withings is a Django app for integrating a user's Withings data into your
site.

It handles the details of getting your app authorized to access your user's
Withings data via the Withings API.

Documentation is hosted on <http://django-withings.readthedocs.org>.
